@@ -175,7 +175,7 @@ class AnonRateThrottle(SimpleRateThrottle):
             if request['user']['is_authenticated']:
                 return None  # Only throttle unauthenticated requests.
         except:
-            if request.user.is_authenticated:
+            if request.user['is_authenticated']:
                 return None  # Only throttle unauthenticated requests.
         return self.cache_format % {
             'scope': self.scope,
@@ -196,12 +196,12 @@ class UserRateThrottle(SimpleRateThrottle):
     def get_cache_key(self, request, view):
         try:
             if request['user']['is_authenticated']:
-                ident = request['user']['pk']
+                ident = request['user']['id']
             else:
                 ident = self.get_ident(request)
         except:
-            if request.user.is_authenticated:
-                ident = request.user.pk
+            if request.user['is_authenticated']:
+                ident = request.user['id']
             else:
                 ident = self.get_ident(request)
 
@@ -250,12 +250,12 @@ class ScopedRateThrottle(SimpleRateThrottle):
         """
         try:
             if request['user']['is_authenticated']:
-                ident = request['user']['pk']
+                ident = request['user']['id']
             else:
                 ident = self.get_ident(request)
         except:
-            if request.user.is_authenticated:
-                ident = request.user.pk
+            if request.user['is_authenticated']:
+                ident = request.user['id']
             else:
                 ident = self.get_ident(request)
 
