@@ -3,6 +3,8 @@ from django.db import models
 
 
 class Base(models.Model):  # base class should subclass 'django.db.models.Model'
+    id = models.AutoField(primary_key=True)
+
     STATUS_CHOICES = (
         ('draft', 'Draft'),
         ('published', 'Published'),
@@ -17,6 +19,8 @@ class Base(models.Model):  # base class should subclass 'django.db.models.Model'
                               db_index=True,
                               choices=STATUS_CHOICES,
                               default='draft')
+    active = models.BooleanField(
+        default=False)
 
     class Meta:
         abstract = True  # Set this model as Abstract
