@@ -3,7 +3,7 @@ from rest_framework import permissions
 
 class ActivePermission(permissions.BasePermission):
     def has_permission(self, request, view):
-        if request.user.is_authenticated:
+        if request.user['is_authenticated']:
             return True
         else:
             return False
